-- NAV TECHDAYS 2014 - Alain Krikilion

-- Simple 2 full with transactionlog backups

USE master

-- create a database
CREATE DATABASE [START_TL_BACKUPS]
 CONTAINMENT = NONE
 ON  PRIMARY 
( NAME = N'START_TL_BACKUPS_Data', FILENAME = N'C:\NAVTECHDAYS2014\START_TL_BACKUPS_data.mdf' , SIZE = 10MB , MAXSIZE = UNLIMITED, FILEGROWTH = 1MB )
 LOG ON 
( NAME = N'START_TL_BACKUPS_Log', FILENAME = N'C:\NAVTECHDAYS2014\START_TL_BACKUPS_log.ldf' , SIZE = 10MB , MAXSIZE = 100MB , FILEGROWTH = 1MB)
GO



-- make sure it is in SIMPLE recovery model
ALTER DATABASE [START_TL_BACKUPS] SET RECOVERY SIMPLE
GO



-- create a table and do an insert just for the fun of it
USE [START_TL_BACKUPS]
GO

CREATE TABLE SomeTable (ID INT IDENTITY, txt1 CHAR(100),txt2 CHAR(100))
GO

INSERT INTO SomeTable (txt1,txt2) VALUES ('NAVTECHDAYS2014','I love NAV & SQL');
GO





-- make a FULL backup. WE HAVE A FULL BACKUP NOW!
BACKUP DATABASE [START_TL_BACKUPS] 
  TO  DISK = N'C:\NAVTECHDAYS2014\START_TL_BACKUPS_FULL_BEFORE_FULLRECOVERY.BAK' 
  WITH NOFORMAT, NOINIT,  NAME = N'Full Database Backup', SKIP, NOREWIND, NOUNLOAD,  STATS = 10
GO
--btw : you can see it also backed up the log-file!



-- Put the DB in FULL recovery model
ALTER DATABASE [START_TL_BACKUPS] SET RECOVERY FULL
GO




-- We already have a FULL backup, so we can make our first TL backup
BACKUP LOG [START_TL_BACKUPS] TO  DISK = N'C:\NAVTECHDAYS2014\START_TL_BACKUPS_10100_TL_BEFORE_FULLRECOVERY.TRN' 
WITH NOFORMAT, NOINIT,  NAME = N'TL Database Backup', SKIP, NOREWIND, NOUNLOAD,  STATS = 10
GO





-- We need to do a FULL backup AFTER putting the DB in FULL recovery model
-- We need to do that to INITIALIZE the FULL recovery model
BACKUP DATABASE [START_TL_BACKUPS] 
  TO  DISK = N'C:\NAVTECHDAYS2014\START_TL_BACKUPS_FULL_AFTER_FULLRECOVERY.BAK' 
  WITH NOFORMAT, NOINIT,  NAME = N'Full Database Backup', SKIP, NOREWIND, NOUNLOAD,  STATS = 10
GO






-- Retry a TL backup.
BACKUP LOG [START_TL_BACKUPS] TO  DISK = N'C:\NAVTECHDAYS2014\START_TL_BACKUPS_10100_TL_AFTER_FULLRECOVERY.TRN' 
WITH NOFORMAT, NOINIT,  NAME = N'TL Database Backup', SKIP, NOREWIND, NOUNLOAD,  STATS = 10
GO







--
--Lets try to initialize the FULL recovery model with a DIFF backup
--


-- lets destroy our FULL recovery model
ALTER DATABASE [START_TL_BACKUPS] SET RECOVERY SIMPLE
GO




-- make a FULL backup. WE HAVE A FULL BACKUP NOW!
BACKUP DATABASE [START_TL_BACKUPS] 
  TO  DISK = N'C:\NAVTECHDAYS2014\START_TL_BACKUPS_FULL_BEFORE_FULLRECOVERY_2.BAK' 
  WITH NOFORMAT, NOINIT,  NAME = N'Full Database Backup', SKIP, NOREWIND, NOUNLOAD,  STATS = 10
GO




-- Let's confirm we still can't take a TL backup
BACKUP LOG [START_TL_BACKUPS] TO  DISK = N'C:\NAVTECHDAYS2014\START_TL_BACKUPS_10100_TL_BEFORE_FULLRECOVERY.TRN' 
WITH NOFORMAT, NOINIT,  NAME = N'TL Database Backup', SKIP, NOREWIND, NOUNLOAD,  STATS = 10
GO




-- Put the DB in FULL recovery model
ALTER DATABASE [START_TL_BACKUPS] SET RECOVERY FULL
GO




-- Now let's try to initialize the FULL recovery model with a DIFF backup
BACKUP DATABASE [START_TL_BACKUPS] 
  TO  DISK = N'C:\NAVTECHDAYS2014\START_TL_BACKUPS_DIFF_AFTER_FULL_RECOVERY.bak' 
  WITH  DIFFERENTIAL , NOFORMAT, NOINIT,  NAME = N'11000_START_TL_BACKUPS-Diff Database Backup', SKIP, NOREWIND, NOUNLOAD,  STATS = 10
GO




-- Can we do our first TL backup? We DIDN'T initialize the FULL recovery model with a FULL backup but with a DIFF backup
BACKUP LOG [START_TL_BACKUPS] TO  DISK = N'C:\NAVTECHDAYS2014\START_TL_BACKUPS_10100_TL_AFTER_FULLRECOVERY.TRN' 
WITH NOFORMAT, NOINIT,  NAME = N'TL Database Backup', SKIP, NOREWIND, NOUNLOAD,  STATS = 10
GO





















-- YES, WE CAN!




-- Let's clean up the mess in the DB
DROP DATABASE [START_TL_BACKUPS]
GO



-- Someone is still using the DB. Let's check the SPID and see who it is. And use a kill command
sp_who2



-- let's kill the session
kill xxx







-- Oh. I am blocking the DROP DATABASE....





-- Change the database to master
USE master
GO



-- and drop our messy database.
DROP DATABASE [START_TL_BACKUPS]
GO
